ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - b -

- bAngle : ProSHADE_internal_data::ProSHADE_data
- BicubicInterpolator() : ProSHADE_internal_maths::BicubicInterpolator
- blurFactor : ProSHADE_settings
- boundsExtraSpace : ProSHADE_settings
- boundsSimilarityThreshold : ProSHADE_settings